Пакет импорта данных ФИАС в Elasticsearch
=========================================

Реализованный функционал
------------------------

* Пакет ``fiases`` позволяет осуществить  импорт таблиц ``ADDROBJ`` и ``HOUSES`` в формате XML из
ФИАС (Федеральной информационной адресной системы)  в ``Elasticsearch``
* Обновление до актуальной версии на сайте ФИАС
* Создание индекса для полнотекстового поиска

Установка
---------

pip install fiases

Зависимости (устанавливаются автоматически)
-------------------------------------------

* elasticsearch>=7.1.0,
* elasticsearch-dsl>=7.1.0,
* hurry.filesize>=0.9,
* rarfile>=3.1,
* tqdm>=4.40.1,
* urllib3>=1.25.7,
* lxml>=4.4.2,
* py-dateutil>=2.2

